==> haskell-concise-0.1.0.1-33-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concise
version: 0.1.0.1
id: concise-0.1.0.1-5MZQjRgFsV47wyqzpLfCTD
key: concise-0.1.0.1-5MZQjRgFsV47wyqzpLfCTD
license: BSD-3-Clause
copyright: Copyright (C) 2016  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-concise
synopsis: Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.
category: Data, Lenses
abi: ad1cfd4f7700d0a00985e1995376b671
exposed: True
exposed-modules:
    Control.Lens.Cons.Extras
import-dirs: /usr/lib/ghc-8.4.3/site-local/concise-0.1.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/concise-0.1.0.1
hs-libraries: HSconcise-0.1.0.1-5MZQjRgFsV47wyqzpLfCTD
depends:
    base-4.11.1.0 lens-4.16.1-CI8r7lJC6eG7FYMQb0SOhg text-1.2.3.0
    bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             lens-4.16.1-CI8r7lJC6eG7FYMQb0SOhg=b69b1df8d1b879a48e7570c642b41b72
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html: /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concise-0.1.0.1-54-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concise
version: 0.1.0.1
id: concise-0.1.0.1-EfTAeLRb5W43ICo6BzrPby
key: concise-0.1.0.1-EfTAeLRb5W43ICo6BzrPby
license: BSD-3-Clause
copyright: Copyright (C) 2016  Fraser Tweedale
maintainer: frase@frase.id.au
author: Fraser Tweedale
homepage: https://github.com/frasertweedale/hs-concise
synopsis: Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.
category: Data, Lenses
abi: b5fcc1fe322dbcbfc0786ac3202e042c
exposed: True
exposed-modules:
    Control.Lens.Cons.Extras
import-dirs: /usr/lib/ghc-8.4.3/site-local/concise-0.1.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/concise-0.1.0.1
hs-libraries: HSconcise-0.1.0.1-EfTAeLRb5W43ICo6BzrPby
depends:
    base-4.11.1.0 lens-4.17-3gLkoewbk5233egn7b0389 text-1.2.3.0
    bytestring-0.10.8.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             lens-4.17-3gLkoewbk5233egn7b0389=f6b290218e3a39ad8e4738eb709d28f3
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html: /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
